@@ -3,6 +3,11 @@ import re
 import bs4 as bs
 
 
+def sanitize_html(html_str):
+    """Sanitize HTML string"""
+    return re.sub(r"[\n\r \t]+", " ", html_str).strip()
+
+
 class AssertElementMixin:
     def assertElementContains(  # noqa
         self,
@@ -18,6 +23,6 @@ class AssertElementMixin:
         if len(element) > 1:
             raise Exception(f"More than one element found: {html_element}")
         soup_1 = bs.BeautifulSoup(element_text, "html.parser")
-        element_txt = re.sub(" +", " ", str(element[0].prettify())).strip()
-        soup_1_txt = re.sub(" +", " ", str(soup_1.prettify())).strip()
+        element_txt = sanitize_html(element[0].prettify())
+        soup_1_txt = sanitize_html(soup_1.prettify())
         self.assertEqual(element_txt, soup_1_txt)
